soplex: Linear optimization solver using the revised simplex method
===================================================================

Description
-----------

SoPlex is an optimization package for solving linear programming
problems (LPs) based on an advanced implementation of the primal and
dual revised simplex algorithm. It provides special support for the
exact solution of LPs with rational input data.


License
-------

Apache License, Version 2.0


Upstream Contact
----------------

https://github.com/scipopt/soplex
